@@ -316,7 +316,40 @@ class TextWatermark:
         return json.dumps(params, ensure_ascii=False)
 
     @staticmethod
-    def init_from_params(params: dict, text: str, dont_check_version: bool = False):
+    def check_if_enough_space(params: Any, text: str, dont_check_version: bool = False):
+        """check if there if enough space to insert watermark to text
+
+        Args:
+            params (Any): praram string export by export_params         
+            text (str): text to be watermarked     
+            dont_check_version (bool, optional): if True then skip check version
+
+        Returns:
+            (bool): True or False
+        """
+        wm_init = TextWatermark.init_from_params(
+            params=params, text=text, dont_check_version=dont_check_version
+        )
+
+        match wm_init.wmt.method.value:
+            case WMMethod.FIND_AND_REPLACE:
+                new_text = text[wm_init.start_at:]
+                times = wm_init.wmt.check_find_and_replace_space(
+                    new_text, wm_init.wm_fixed_len
+                )
+                if times < 1:
+                    return False
+            case WMMethod.INSERT_INTO_POSITION:
+                if wm_init.start_at > len(text):
+                    return False
+            case WMMethod.APPEND_TO_CHAR | WMMethod.APPEND_AS_BINARY | WMMethod.DECORATE_EACH_CHAR:
+                if wm_init.wm_fixed_len > (len(text) - wm_init.start_at):
+                    return False
+
+        return True
+
+    @staticmethod
+    def init_from_params(params: Any, text: str, dont_check_version: bool = False):
         """Import watermark params from json string
 
         Args:
@@ -334,7 +367,8 @@ class TextWatermark:
             params = json.loads(params)
 
         if not dont_check_version and __version__ != params["version"]:
-            raise ValueError(f'Version mismatch: {__version__}!= {params["version"]}')
+            raise ValueError(
+                f'Version mismatch: {__version__}!= {params["version"]}')
 
         wm_init = TextWatermark(
             wm_mode=WMMode[params["wm_mode"]],
